@@ -9,8 +9,6 @@
 #endif
 #include <QDesktopServices>
 
-#include <qwt_plot_renderer.h>
-
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
@@ -39,18 +37,21 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    /* insert Qwt plotters in ui */
+    /* insert QChartView plotters in ui */
 
     QHBoxLayout *ly1 = new QHBoxLayout(ui->sealedVolumePlotWidget);
     sealedPlot = new Plot(tr("Sealed volume frequency response"), ui->sealedVolumePlotWidget);
+    sealedPlot->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored);
     ly1->insertWidget(0, sealedPlot);
 
     QHBoxLayout *ly2 = new QHBoxLayout(ui->portedPlotWidget);
     portedPlot = new Plot(tr("Ported volume frequency response"), ui->portedPlotWidget);
+    portedPlot->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored);
     ly2->insertWidget(0, portedPlot);
 
     QHBoxLayout *ly3 = new QHBoxLayout(ui->bandpassPlotWidget);
     bandpassPlot = new Plot(tr("Bandpass volumes frequency response"), ui->bandpassPlotWidget);
+    bandpassPlot->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored);
     ly3->insertWidget(0, bandpassPlot);
 
     /* test db */
@@ -274,16 +275,13 @@ void MainWindow::syncUiFromCurrentSealedBox(const SealedBox& box)
 {
     ui->sealedVolumeDoubleSpinBox->setValue(box.getVolume());
 
-    QList<double> xlist;
-    QList<double> ylist;
-
     System s(currentSpeaker, &box, currentSpeakerNumber);
-    for (int f = sealedPlot->getXmin(); f < portedPlot->getXmax(); f++) {
+    sealedPlot->clear();
+    for (double f = sealedPlot->getXmin(); f < portedPlot->getXmax(); f *= pow(10, 1.0/100.0)) {
         double db = s.response(f);
-        xlist.append(f), ylist.append(db);
+        sealedPlot->appendPointF(QPointF(f, db));
     }
-
-    sealedPlot->plot(xlist, ylist);
+    sealedPlot->draw3dbVLine();
 }
 
 void MainWindow::syncUiFromCurrentPortedBox(const PortedBox& box)
@@ -296,17 +294,13 @@ void MainWindow::syncUiFromCurrentPortedBox(const PortedBox& box)
     ui->portedPortSlotHeightLineEdit->setText(QString::number(box.getSlotHeight(), 'f', 2));
     ui->portedPortLengthLineEdit->setText(QString::number(box.getPortLen(), 'f', 2));
 
-
-    QList<double> xlist;
-    QList<double> ylist;
-
     System s(currentSpeaker, &box, currentSpeakerNumber);
-    for (int f = portedPlot->getXmin(); f < portedPlot->getXmax(); f++) {
+    portedPlot->clear();
+    for (double f = portedPlot->getXmin(); f < portedPlot->getXmax(); f *= pow(10, 1.0/100.0)) {
         double db = s.response(f);
-        xlist.append(f), ylist.append(db);
+        portedPlot->appendPointF(QPointF(f, db));
     }
-
-    portedPlot->plot(xlist, ylist);
+    portedPlot->draw3dbVLine();
 }
 
 void MainWindow::syncUiFromCurrentBandPassBox(const BandPassBox& box)
@@ -318,16 +312,13 @@ void MainWindow::syncUiFromCurrentBandPassBox(const BandPassBox& box)
     ui->bandPassPortDiameterDoubleSpinBox->setValue(box.getPortedBoxPortDiam());
     ui->bandPassPortLengthLineEdit->setText(QString::number(box.getPortedBoxPortLen(), 'f', 2));
 
-    QList<double> xlist;
-    QList<double> ylist;
-
     System s(currentSpeaker, &box, currentSpeakerNumber);
-    for (int f = bandpassPlot->getXmin(); f < bandpassPlot->getXmax(); f++) {
+    bandpassPlot->clear();
+    for (double f = bandpassPlot->getXmin(); f < bandpassPlot->getXmax(); f *= pow(10, 1.0/100.0)) {
         double db = s.response(f);
-        xlist.append(f), ylist.append(db);
+        bandpassPlot->appendPointF(QPointF(f, db));
     }
-
-    bandpassPlot->plot(xlist, ylist);
+    bandpassPlot->draw3dbVLine();
 }
 
 void MainWindow::setCurrentSpeaker(const Speaker &spk)
@@ -352,29 +343,33 @@ bool MainWindow::print(QPrinter *printer)
 
     currentSpeaker.render(&painter, QRectF(page.left(), page.top(), page.width(), step));
 
-    QwtPlotRenderer plotter(this);
-
     if (ui->tabWidget->currentWidget() == ui->sealedTab) {
         System s(currentSpeaker, &currentSealedBox, currentSpeakerNumber);
         s.render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() / 16));
         step += page.height() / 16;
         currentSealedBox.render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() / 16));
         step += page.height() / 16;
-        plotter.render(sealedPlot, &painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
+        sealedPlot->setUseOpenGL(false);
+        sealedPlot->render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
+        sealedPlot->setUseOpenGL(true);
     } else if (ui->tabWidget->currentWidget() == ui->portedTab) {
         System s(currentSpeaker, &currentPortedBox, currentSpeakerNumber);
         s.render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() / 16));
         step += page.height() / 16;
         currentPortedBox.render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() / 16));
         step += page.height() / 16;
-        plotter.render(portedPlot, &painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
+        portedPlot->setUseOpenGL(false);
+        portedPlot->render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
+        portedPlot->setUseOpenGL(true);
     } else {
         System s(currentSpeaker, &currentBandPassBox, currentSpeakerNumber);
         s.render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height()/ 16));
         step += page.height() / 16;
         currentBandPassBox.render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() / 16));
         step += page.height() / 16;
-        plotter.render(bandpassPlot, &painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
+        bandpassPlot->setUseOpenGL(false);
+        bandpassPlot->render(&painter, QRectF(page.left(), page.top() + step, page.width(), page.height() - step));
+        bandpassPlot->setUseOpenGL(true);
     }
 
     painter.end();
