@@ -280,7 +280,7 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="1031"/>
-        <location filename="mainwindow.cpp" line="575"/>
+        <location filename="mainwindow.cpp" line="580"/>
         <source>About QSpeakers</source>
         <translation type="unfinished"></translation>
     </message>
@@ -464,7 +464,7 @@
     </message>
     <message>
         <location filename="mainwindow.cpp" line="180"/>
-        <location filename="mainwindow.cpp" line="218"/>
+        <location filename="mainwindow.cpp" line="223"/>
         <source>Project not saved</source>
         <translation type="unfinished"></translation>
     </message>
@@ -479,38 +479,61 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="219"/>
+        <location filename="mainwindow.cpp" line="224"/>
         <source>The current project has not been saved. Exit anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="404"/>
+        <location filename="mainwindow.cpp" line="409"/>
         <source>Removal confirmation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="405"/>
+        <location filename="mainwindow.cpp" line="410"/>
         <source>Do you really want to remove this loudspeaker from the database?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="576"/>
+        <location filename="mainwindow.cpp" line="581"/>
         <source>QSpeakers version </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="696"/>
-        <location filename="mainwindow.cpp" line="721"/>
+        <location filename="mainwindow.cpp" line="701"/>
+        <location filename="mainwindow.cpp" line="726"/>
         <source>Unsaved speaker</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="697"/>
-        <location filename="mainwindow.cpp" line="722"/>
+        <location filename="mainwindow.cpp" line="702"/>
+        <location filename="mainwindow.cpp" line="727"/>
         <source>This speaker is not present in the database. Would you like to insert it before to continue?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>Plot</name>
+    <message>
+        <location filename="plot.cpp" line="140"/>
+        <source>Frequency [Hz]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="plot.cpp" line="152"/>
+        <source>Sound pressure [dB]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="plot.cpp" line="161"/>
+        <source>Peak: %1 dB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="plot.cpp" line="172"/>
+        <source>%1 dB at %2 Hz</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
